"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_ApiManagement(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_FIELD_NUMBER: builtins.int
    SERVICE_USERS_FIELD_NUMBER: builtins.int
    SERVICE_API_VERSION_SETS_FIELD_NUMBER: builtins.int
    SERVICE_APIS_FIELD_NUMBER: builtins.int
    SERVICE_APIS_DIAGNOSTICS_FIELD_NUMBER: builtins.int
    SERVICE_APIS_OPERATIONS_FIELD_NUMBER: builtins.int
    SERVICE_APIS_OPERATIONS_POLICIES_FIELD_NUMBER: builtins.int
    SERVICE_APIS_OPERATIONS_TAGS_FIELD_NUMBER: builtins.int
    SERVICE_APIS_POLICIES_FIELD_NUMBER: builtins.int
    SERVICE_APIS_TAG_DESCRIPTIONS_FIELD_NUMBER: builtins.int
    SERVICE_APIS_TAGS_FIELD_NUMBER: builtins.int
    SERVICE_AUTHORIZATION_SERVERS_FIELD_NUMBER: builtins.int
    SERVICE_BACKENDS_FIELD_NUMBER: builtins.int
    SERVICE_CERTIFICATES_FIELD_NUMBER: builtins.int
    SERVICE_DIAGNOSTICS_FIELD_NUMBER: builtins.int
    SERVICE_GATEWAYS_FIELD_NUMBER: builtins.int
    SERVICE_GATEWAYS_APIS_FIELD_NUMBER: builtins.int
    SERVICE_GATEWAYS_HOSTNAME_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    SERVICE_GROUPS_FIELD_NUMBER: builtins.int
    SERVICE_GROUPS_USERS_FIELD_NUMBER: builtins.int
    SERVICE_IDENTITY_PROVIDERS_FIELD_NUMBER: builtins.int
    SERVICE_LOGGERS_FIELD_NUMBER: builtins.int
    SERVICE_NAMED_VALUES_FIELD_NUMBER: builtins.int
    SERVICE_NOTIFICATIONS_FIELD_NUMBER: builtins.int
    SERVICE_OPENID_CONNECT_PROVIDERS_FIELD_NUMBER: builtins.int
    SERVICE_POLICIES_FIELD_NUMBER: builtins.int
    SERVICE_PRODUCTS_FIELD_NUMBER: builtins.int
    SERVICE_SUBSCRIPTIONS_FIELD_NUMBER: builtins.int
    @property
    def service(self) -> global___Service: ...
    @property
    def service_users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceUsers]: ...
    @property
    def service_api_version_sets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceApiVersionSets]: ...
    @property
    def service_apis(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceApis]: ...
    @property
    def service_apis_diagnostics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceApisDiagnostics]: ...
    @property
    def service_apis_operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceApisOperations]: ...
    @property
    def service_apis_operations_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceApisOperationsPolicies]: ...
    @property
    def service_apis_operations_tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceApisOperationsTags]: ...
    @property
    def service_apis_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceApisPolicies]: ...
    @property
    def service_apis_tag_descriptions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceApisTagDescriptions]: ...
    @property
    def service_apis_tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceApisTags]: ...
    @property
    def service_authorization_servers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceAuthorizationServers]: ...
    @property
    def service_backends(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceBackends]: ...
    @property
    def service_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceCertificates]: ...
    @property
    def service_diagnostics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceDiagnostics]: ...
    @property
    def service_gateways(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceGateways]: ...
    @property
    def service_gateways_apis(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceGatewaysApis]: ...
    @property
    def service_gateways_hostname_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceGatewaysHostnameConfigurations]: ...
    @property
    def service_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceGroups]: ...
    @property
    def service_groups_users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceGroupsUsers]: ...
    @property
    def service_identity_providers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceIdentityProviders]: ...
    @property
    def service_loggers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceLoggers]: ...
    @property
    def service_named_values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceNamedValues]: ...
    @property
    def service_notifications(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceNotifications]: ...
    @property
    def service_openid_connect_providers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceOpenidConnectProviders]: ...
    @property
    def service_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServicePolicies]: ...
    @property
    def service_products(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceProducts]: ...
    @property
    def service_subscriptions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceSubscriptions]: ...
    def __init__(
        self,
        *,
        service: global___Service | None = ...,
        service_users: collections.abc.Iterable[global___ServiceUsers] | None = ...,
        service_api_version_sets: collections.abc.Iterable[global___ServiceApiVersionSets] | None = ...,
        service_apis: collections.abc.Iterable[global___ServiceApis] | None = ...,
        service_apis_diagnostics: collections.abc.Iterable[global___ServiceApisDiagnostics] | None = ...,
        service_apis_operations: collections.abc.Iterable[global___ServiceApisOperations] | None = ...,
        service_apis_operations_policies: collections.abc.Iterable[global___ServiceApisOperationsPolicies] | None = ...,
        service_apis_operations_tags: collections.abc.Iterable[global___ServiceApisOperationsTags] | None = ...,
        service_apis_policies: collections.abc.Iterable[global___ServiceApisPolicies] | None = ...,
        service_apis_tag_descriptions: collections.abc.Iterable[global___ServiceApisTagDescriptions] | None = ...,
        service_apis_tags: collections.abc.Iterable[global___ServiceApisTags] | None = ...,
        service_authorization_servers: collections.abc.Iterable[global___ServiceAuthorizationServers] | None = ...,
        service_backends: collections.abc.Iterable[global___ServiceBackends] | None = ...,
        service_certificates: collections.abc.Iterable[global___ServiceCertificates] | None = ...,
        service_diagnostics: collections.abc.Iterable[global___ServiceDiagnostics] | None = ...,
        service_gateways: collections.abc.Iterable[global___ServiceGateways] | None = ...,
        service_gateways_apis: collections.abc.Iterable[global___ServiceGatewaysApis] | None = ...,
        service_gateways_hostname_configurations: collections.abc.Iterable[global___ServiceGatewaysHostnameConfigurations] | None = ...,
        service_groups: collections.abc.Iterable[global___ServiceGroups] | None = ...,
        service_groups_users: collections.abc.Iterable[global___ServiceGroupsUsers] | None = ...,
        service_identity_providers: collections.abc.Iterable[global___ServiceIdentityProviders] | None = ...,
        service_loggers: collections.abc.Iterable[global___ServiceLoggers] | None = ...,
        service_named_values: collections.abc.Iterable[global___ServiceNamedValues] | None = ...,
        service_notifications: collections.abc.Iterable[global___ServiceNotifications] | None = ...,
        service_openid_connect_providers: collections.abc.Iterable[global___ServiceOpenidConnectProviders] | None = ...,
        service_policies: collections.abc.Iterable[global___ServicePolicies] | None = ...,
        service_products: collections.abc.Iterable[global___ServiceProducts] | None = ...,
        service_subscriptions: collections.abc.Iterable[global___ServiceSubscriptions] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["service", b"service"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["service", b"service", "service_api_version_sets", b"service_api_version_sets", "service_apis", b"service_apis", "service_apis_diagnostics", b"service_apis_diagnostics", "service_apis_operations", b"service_apis_operations", "service_apis_operations_policies", b"service_apis_operations_policies", "service_apis_operations_tags", b"service_apis_operations_tags", "service_apis_policies", b"service_apis_policies", "service_apis_tag_descriptions", b"service_apis_tag_descriptions", "service_apis_tags", b"service_apis_tags", "service_authorization_servers", b"service_authorization_servers", "service_backends", b"service_backends", "service_certificates", b"service_certificates", "service_diagnostics", b"service_diagnostics", "service_gateways", b"service_gateways", "service_gateways_apis", b"service_gateways_apis", "service_gateways_hostname_configurations", b"service_gateways_hostname_configurations", "service_groups", b"service_groups", "service_groups_users", b"service_groups_users", "service_identity_providers", b"service_identity_providers", "service_loggers", b"service_loggers", "service_named_values", b"service_named_values", "service_notifications", b"service_notifications", "service_openid_connect_providers", b"service_openid_connect_providers", "service_policies", b"service_policies", "service_products", b"service_products", "service_subscriptions", b"service_subscriptions", "service_users", b"service_users"]) -> None: ...

global___Microsoft_ApiManagement = Microsoft_ApiManagement

@typing_extensions.final
class ServiceUsers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    APP_TYPE_FIELD_NUMBER: builtins.int
    CONFIRMATION_FIELD_NUMBER: builtins.int
    EMAIL_FIELD_NUMBER: builtins.int
    FIRST_NAME_FIELD_NUMBER: builtins.int
    IDENTITIES_FIELD_NUMBER: builtins.int
    LAST_NAME_FIELD_NUMBER: builtins.int
    NOTE_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    app_type: builtins.str
    confirmation: builtins.str
    email: builtins.str
    first_name: builtins.str
    @property
    def identities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UserIdentityContract]: ...
    last_name: builtins.str
    note: builtins.str
    password: builtins.str
    state: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        app_type: builtins.str = ...,
        confirmation: builtins.str = ...,
        email: builtins.str = ...,
        first_name: builtins.str = ...,
        identities: collections.abc.Iterable[global___UserIdentityContract] | None = ...,
        last_name: builtins.str = ...,
        note: builtins.str = ...,
        password: builtins.str = ...,
        state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_type", b"app_type", "confirmation", b"confirmation", "email", b"email", "first_name", b"first_name", "identities", b"identities", "last_name", b"last_name", "name", b"name", "note", b"note", "password", b"password", "resource_info", b"resource_info", "state", b"state"]) -> None: ...

global___ServiceUsers = ServiceUsers

@typing_extensions.final
class UserIdentityContract(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    PROVIDER_FIELD_NUMBER: builtins.int
    id: builtins.str
    provider: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        provider: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "provider", b"provider"]) -> None: ...

global___UserIdentityContract = UserIdentityContract

@typing_extensions.final
class ServiceTenant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    PRIMARY_KEY_FIELD_NUMBER: builtins.int
    PRINCIPAL_ID_FIELD_NUMBER: builtins.int
    SECONDARY_KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    enabled: builtins.bool
    primary_key: builtins.str
    principal_id: builtins.str
    secondary_key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        enabled: builtins.bool = ...,
        primary_key: builtins.str = ...,
        principal_id: builtins.str = ...,
        secondary_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "name", b"name", "primary_key", b"primary_key", "principal_id", b"principal_id", "resource_info", b"resource_info", "secondary_key", b"secondary_key"]) -> None: ...

global___ServiceTenant = ServiceTenant

@typing_extensions.final
class ServiceTemplates(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    BODY_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    SUBJECT_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    body: builtins.str
    description: builtins.str
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EmailTemplateParametersContractProperties]: ...
    subject: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        body: builtins.str = ...,
        description: builtins.str = ...,
        parameters: collections.abc.Iterable[global___EmailTemplateParametersContractProperties] | None = ...,
        subject: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["body", b"body", "description", b"description", "name", b"name", "parameters", b"parameters", "resource_info", b"resource_info", "subject", b"subject", "title", b"title"]) -> None: ...

global___ServiceTemplates = ServiceTemplates

@typing_extensions.final
class EmailTemplateParametersContractProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    name: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        name: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "name", b"name", "title", b"title"]) -> None: ...

global___EmailTemplateParametersContractProperties = EmailTemplateParametersContractProperties

@typing_extensions.final
class ServiceTags(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    display_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        display_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_name", b"display_name", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServiceTags = ServiceTags

@typing_extensions.final
class ServiceSubscriptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ALLOW_TRACING_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    OWNER_ID_FIELD_NUMBER: builtins.int
    PRIMARY_KEY_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    SECONDARY_KEY_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    allow_tracing: builtins.bool
    display_name: builtins.str
    owner_id: builtins.str
    primary_key: builtins.str
    scope: builtins.str
    secondary_key: builtins.str
    state: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        allow_tracing: builtins.bool = ...,
        display_name: builtins.str = ...,
        owner_id: builtins.str = ...,
        primary_key: builtins.str = ...,
        scope: builtins.str = ...,
        secondary_key: builtins.str = ...,
        state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_tracing", b"allow_tracing", "display_name", b"display_name", "name", b"name", "owner_id", b"owner_id", "primary_key", b"primary_key", "resource_info", b"resource_info", "scope", b"scope", "secondary_key", b"secondary_key", "state", b"state"]) -> None: ...

global___ServiceSubscriptions = ServiceSubscriptions

@typing_extensions.final
class ServiceSchemas(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class DocumentEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ValueEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DOCUMENT_FIELD_NUMBER: builtins.int
    SCHEMA_TYPE_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    description: builtins.str
    @property
    def document(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    schema_type: builtins.str
    @property
    def value(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        document: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        schema_type: builtins.str = ...,
        value: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "document", b"document", "name", b"name", "resource_info", b"resource_info", "schema_type", b"schema_type", "value", b"value"]) -> None: ...

global___ServiceSchemas = ServiceSchemas

@typing_extensions.final
class ServiceProductsTags(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServiceProductsTags = ServiceProductsTags

@typing_extensions.final
class ServiceProductsPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    format: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        format: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["format", b"format", "name", b"name", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___ServiceProductsPolicies = ServiceProductsPolicies

@typing_extensions.final
class ServiceProductsGroups(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServiceProductsGroups = ServiceProductsGroups

@typing_extensions.final
class ServiceProductsApis(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServiceProductsApis = ServiceProductsApis

@typing_extensions.final
class ServiceProducts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    APPROVAL_REQUIRED_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_REQUIRED_FIELD_NUMBER: builtins.int
    SUBSCRIPTIONS_LIMIT_FIELD_NUMBER: builtins.int
    TERMS_FIELD_NUMBER: builtins.int
    SERVICE_PRODUCTS_TAGS_FIELD_NUMBER: builtins.int
    SERVICE_PRODUCTS_APIS_FIELD_NUMBER: builtins.int
    SERVICE_PRODUCTS_GROUPS_FIELD_NUMBER: builtins.int
    SERVICE_PRODUCTS_POLICIES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    approval_required: builtins.bool
    description: builtins.str
    display_name: builtins.str
    state: builtins.str
    subscription_required: builtins.bool
    subscriptions_limit: builtins.int
    terms: builtins.str
    @property
    def service_products_tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceProductsTags]: ...
    @property
    def service_products_apis(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceProductsApis]: ...
    @property
    def service_products_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceProductsGroups]: ...
    @property
    def service_products_policies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceProductsPolicies]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        approval_required: builtins.bool = ...,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        state: builtins.str = ...,
        subscription_required: builtins.bool = ...,
        subscriptions_limit: builtins.int = ...,
        terms: builtins.str = ...,
        service_products_tags: collections.abc.Iterable[global___ServiceProductsTags] | None = ...,
        service_products_apis: collections.abc.Iterable[global___ServiceProductsApis] | None = ...,
        service_products_groups: collections.abc.Iterable[global___ServiceProductsGroups] | None = ...,
        service_products_policies: collections.abc.Iterable[global___ServiceProductsPolicies] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["approval_required", b"approval_required", "description", b"description", "display_name", b"display_name", "name", b"name", "resource_info", b"resource_info", "service_products_apis", b"service_products_apis", "service_products_groups", b"service_products_groups", "service_products_policies", b"service_products_policies", "service_products_tags", b"service_products_tags", "state", b"state", "subscription_required", b"subscription_required", "subscriptions_limit", b"subscriptions_limit", "terms", b"terms"]) -> None: ...

global___ServiceProducts = ServiceProducts

@typing_extensions.final
class ServicePrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    id: builtins.str
    name: builtins.str
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkServiceConnectionState: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        private_link_service_connection_state: global___PrivateLinkServiceConnectionState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "name", b"name", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> None: ...

global___ServicePrivateEndpointConnections = ServicePrivateEndpointConnections

@typing_extensions.final
class ServicePortalsettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___ServicePortalsettings = ServicePortalsettings

@typing_extensions.final
class ServicePortalRevisions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    IS_CURRENT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    description: builtins.str
    is_current: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        is_current: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "is_current", b"is_current", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServicePortalRevisions = ServicePortalRevisions

@typing_extensions.final
class ServicePolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    format: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        format: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["format", b"format", "name", b"name", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___ServicePolicies = ServicePolicies

@typing_extensions.final
class ServiceOpenidConnectProviders(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CLIENT_ID_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    METADATA_ENDPOINT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    client_id: builtins.str
    client_secret: builtins.str
    description: builtins.str
    display_name: builtins.str
    metadata_endpoint: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        client_id: builtins.str = ...,
        client_secret: builtins.str = ...,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        metadata_endpoint: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_id", b"client_id", "client_secret", b"client_secret", "description", b"description", "display_name", b"display_name", "metadata_endpoint", b"metadata_endpoint", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServiceOpenidConnectProviders = ServiceOpenidConnectProviders

@typing_extensions.final
class ServiceNotificationsRecipientUsers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServiceNotificationsRecipientUsers = ServiceNotificationsRecipientUsers

@typing_extensions.final
class ServiceNotificationsRecipientEmails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServiceNotificationsRecipientEmails = ServiceNotificationsRecipientEmails

@typing_extensions.final
class ServiceNotifications(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SERVICE_NOTIFICATIONS_RECIPIENT_USERS_FIELD_NUMBER: builtins.int
    SERVICE_NOTIFICATIONS_RECIPIENT_EMAILS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def service_notifications_recipient_users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceNotificationsRecipientUsers]: ...
    @property
    def service_notifications_recipient_emails(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceNotificationsRecipientEmails]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        service_notifications_recipient_users: collections.abc.Iterable[global___ServiceNotificationsRecipientUsers] | None = ...,
        service_notifications_recipient_emails: collections.abc.Iterable[global___ServiceNotificationsRecipientEmails] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "service_notifications_recipient_emails", b"service_notifications_recipient_emails", "service_notifications_recipient_users", b"service_notifications_recipient_users"]) -> None: ...

global___ServiceNotifications = ServiceNotifications

@typing_extensions.final
class ServiceNamedValues(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    KEY_VAULT_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    display_name: builtins.str
    @property
    def key_vault(self) -> global___KeyVaultContractCreateProperties: ...
    secret: builtins.bool
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        display_name: builtins.str = ...,
        key_vault: global___KeyVaultContractCreateProperties | None = ...,
        secret: builtins.bool = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["key_vault", b"key_vault", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_name", b"display_name", "key_vault", b"key_vault", "name", b"name", "resource_info", b"resource_info", "secret", b"secret", "tags", b"tags", "value", b"value"]) -> None: ...

global___ServiceNamedValues = ServiceNamedValues

@typing_extensions.final
class ServiceLoggers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class CredentialsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CREDENTIALS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    IS_BUFFERED_FIELD_NUMBER: builtins.int
    LOGGER_TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def credentials(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    description: builtins.str
    is_buffered: builtins.bool
    logger_type: builtins.str
    resource_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        credentials: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        description: builtins.str = ...,
        is_buffered: builtins.bool = ...,
        logger_type: builtins.str = ...,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["credentials", b"credentials", "description", b"description", "is_buffered", b"is_buffered", "logger_type", b"logger_type", "name", b"name", "resource_id", b"resource_id", "resource_info", b"resource_info"]) -> None: ...

global___ServiceLoggers = ServiceLoggers

@typing_extensions.final
class ServiceIdentityProviders(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ALLOWED_TENANTS_FIELD_NUMBER: builtins.int
    AUTHORITY_FIELD_NUMBER: builtins.int
    CLIENT_ID_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_FIELD_NUMBER: builtins.int
    PASSWORD_RESET_POLICY_NAME_FIELD_NUMBER: builtins.int
    PROFILE_EDITING_POLICY_NAME_FIELD_NUMBER: builtins.int
    SIGNIN_POLICY_NAME_FIELD_NUMBER: builtins.int
    SIGNIN_TENANT_FIELD_NUMBER: builtins.int
    SIGNUP_POLICY_NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def allowed_tenants(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    authority: builtins.str
    client_id: builtins.str
    client_secret: builtins.str
    password_reset_policy_name: builtins.str
    profile_editing_policy_name: builtins.str
    signin_policy_name: builtins.str
    signin_tenant: builtins.str
    signup_policy_name: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        allowed_tenants: collections.abc.Iterable[builtins.str] | None = ...,
        authority: builtins.str = ...,
        client_id: builtins.str = ...,
        client_secret: builtins.str = ...,
        password_reset_policy_name: builtins.str = ...,
        profile_editing_policy_name: builtins.str = ...,
        signin_policy_name: builtins.str = ...,
        signin_tenant: builtins.str = ...,
        signup_policy_name: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_tenants", b"allowed_tenants", "authority", b"authority", "client_id", b"client_id", "client_secret", b"client_secret", "name", b"name", "password_reset_policy_name", b"password_reset_policy_name", "profile_editing_policy_name", b"profile_editing_policy_name", "resource_info", b"resource_info", "signin_policy_name", b"signin_policy_name", "signin_tenant", b"signin_tenant", "signup_policy_name", b"signup_policy_name", "type", b"type"]) -> None: ...

global___ServiceIdentityProviders = ServiceIdentityProviders

@typing_extensions.final
class ServiceGroupsUsers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServiceGroupsUsers = ServiceGroupsUsers

@typing_extensions.final
class ServiceGroups(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    EXTERNAL_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    description: builtins.str
    display_name: builtins.str
    external_id: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        external_id: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "display_name", b"display_name", "external_id", b"external_id", "name", b"name", "resource_info", b"resource_info", "type", b"type"]) -> None: ...

global___ServiceGroups = ServiceGroups

@typing_extensions.final
class ServiceGatewaysHostnameConfigurations(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    HOSTNAME_FIELD_NUMBER: builtins.int
    HTTP2_ENABLED_FIELD_NUMBER: builtins.int
    NEGOTIATE_CLIENT_CERTIFICATE_FIELD_NUMBER: builtins.int
    TLS10_ENABLED_FIELD_NUMBER: builtins.int
    TLS11_ENABLED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    certificate_id: builtins.str
    hostname: builtins.str
    http2_enabled: builtins.bool
    negotiate_client_certificate: builtins.bool
    tls10_enabled: builtins.bool
    tls11_enabled: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        certificate_id: builtins.str = ...,
        hostname: builtins.str = ...,
        http2_enabled: builtins.bool = ...,
        negotiate_client_certificate: builtins.bool = ...,
        tls10_enabled: builtins.bool = ...,
        tls11_enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_id", b"certificate_id", "hostname", b"hostname", "http2_enabled", b"http2_enabled", "name", b"name", "negotiate_client_certificate", b"negotiate_client_certificate", "resource_info", b"resource_info", "tls10_enabled", b"tls10_enabled", "tls11_enabled", b"tls11_enabled"]) -> None: ...

global___ServiceGatewaysHostnameConfigurations = ServiceGatewaysHostnameConfigurations

@typing_extensions.final
class ServiceGatewaysCertificateAuthorities(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    IS_TRUSTED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    is_trusted: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        is_trusted: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_trusted", b"is_trusted", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServiceGatewaysCertificateAuthorities = ServiceGatewaysCertificateAuthorities

@typing_extensions.final
class ServiceGatewaysApis(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    provisioning_state: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        provisioning_state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "provisioning_state", b"provisioning_state", "resource_info", b"resource_info"]) -> None: ...

global___ServiceGatewaysApis = ServiceGatewaysApis

@typing_extensions.final
class ServiceGateways(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LOCATION_DATA_FIELD_NUMBER: builtins.int
    SERVICE_GATEWAYS_CERTIFICATE_AUTHORITIES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    description: builtins.str
    @property
    def location_data(self) -> global___ResourceLocationDataContract: ...
    @property
    def service_gateways_certificate_authorities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceGatewaysCertificateAuthorities]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        location_data: global___ResourceLocationDataContract | None = ...,
        service_gateways_certificate_authorities: collections.abc.Iterable[global___ServiceGatewaysCertificateAuthorities] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["location_data", b"location_data", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "location_data", b"location_data", "name", b"name", "resource_info", b"resource_info", "service_gateways_certificate_authorities", b"service_gateways_certificate_authorities"]) -> None: ...

global___ServiceGateways = ServiceGateways

@typing_extensions.final
class ResourceLocationDataContract(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CITY_FIELD_NUMBER: builtins.int
    COUNTRY_OR_REGION_FIELD_NUMBER: builtins.int
    DISTRICT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    city: builtins.str
    country_or_region: builtins.str
    district: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        city: builtins.str = ...,
        country_or_region: builtins.str = ...,
        district: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["city", b"city", "country_or_region", b"country_or_region", "district", b"district", "name", b"name"]) -> None: ...

global___ResourceLocationDataContract = ResourceLocationDataContract

@typing_extensions.final
class ServiceDiagnostics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ALWAYS_LOG_FIELD_NUMBER: builtins.int
    BACKEND_FIELD_NUMBER: builtins.int
    FRONTEND_FIELD_NUMBER: builtins.int
    HTTP_CORRELATION_PROTOCOL_FIELD_NUMBER: builtins.int
    LOG_CLIENT_IP_FIELD_NUMBER: builtins.int
    LOGGER_ID_FIELD_NUMBER: builtins.int
    OPERATION_NAME_FORMAT_FIELD_NUMBER: builtins.int
    SAMPLING_FIELD_NUMBER: builtins.int
    VERBOSITY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    always_log: builtins.str
    @property
    def backend(self) -> global___PipelineDiagnosticSettings: ...
    @property
    def frontend(self) -> global___PipelineDiagnosticSettings: ...
    http_correlation_protocol: builtins.str
    log_client_ip: builtins.bool
    logger_id: builtins.str
    operation_name_format: builtins.str
    @property
    def sampling(self) -> global___SamplingSettings: ...
    verbosity: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        always_log: builtins.str = ...,
        backend: global___PipelineDiagnosticSettings | None = ...,
        frontend: global___PipelineDiagnosticSettings | None = ...,
        http_correlation_protocol: builtins.str = ...,
        log_client_ip: builtins.bool = ...,
        logger_id: builtins.str = ...,
        operation_name_format: builtins.str = ...,
        sampling: global___SamplingSettings | None = ...,
        verbosity: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["backend", b"backend", "frontend", b"frontend", "resource_info", b"resource_info", "sampling", b"sampling"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["always_log", b"always_log", "backend", b"backend", "frontend", b"frontend", "http_correlation_protocol", b"http_correlation_protocol", "log_client_ip", b"log_client_ip", "logger_id", b"logger_id", "name", b"name", "operation_name_format", b"operation_name_format", "resource_info", b"resource_info", "sampling", b"sampling", "verbosity", b"verbosity"]) -> None: ...

global___ServiceDiagnostics = ServiceDiagnostics

@typing_extensions.final
class ServiceContentTypesContentItems(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServiceContentTypesContentItems = ServiceContentTypesContentItems

@typing_extensions.final
class ServiceContentTypes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SERVICE_CONTENT_TYPES_CONTENT_ITEMS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def service_content_types_content_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceContentTypesContentItems]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        service_content_types_content_items: collections.abc.Iterable[global___ServiceContentTypesContentItems] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "service_content_types_content_items", b"service_content_types_content_items"]) -> None: ...

global___ServiceContentTypes = ServiceContentTypes

@typing_extensions.final
class ServiceCertificates(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    KEY_VAULT_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    data: builtins.str
    @property
    def key_vault(self) -> global___KeyVaultContractCreateProperties: ...
    password: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        data: builtins.str = ...,
        key_vault: global___KeyVaultContractCreateProperties | None = ...,
        password: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["key_vault", b"key_vault", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "key_vault", b"key_vault", "name", b"name", "password", b"password", "resource_info", b"resource_info"]) -> None: ...

global___ServiceCertificates = ServiceCertificates

@typing_extensions.final
class KeyVaultContractCreateProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTITY_CLIENT_ID_FIELD_NUMBER: builtins.int
    SECRET_IDENTIFIER_FIELD_NUMBER: builtins.int
    identity_client_id: builtins.str
    secret_identifier: builtins.str
    def __init__(
        self,
        *,
        identity_client_id: builtins.str = ...,
        secret_identifier: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity_client_id", b"identity_client_id", "secret_identifier", b"secret_identifier"]) -> None: ...

global___KeyVaultContractCreateProperties = KeyVaultContractCreateProperties

@typing_extensions.final
class ServiceCaches(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CONNECTION_STRING_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    USE_FROM_LOCATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    connection_string: builtins.str
    description: builtins.str
    resource_id: builtins.str
    use_from_location: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        connection_string: builtins.str = ...,
        description: builtins.str = ...,
        resource_id: builtins.str = ...,
        use_from_location: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connection_string", b"connection_string", "description", b"description", "name", b"name", "resource_id", b"resource_id", "resource_info", b"resource_info", "use_from_location", b"use_from_location"]) -> None: ...

global___ServiceCaches = ServiceCaches

@typing_extensions.final
class ServiceBackends(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CREDENTIALS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SERVICE_FABRIC_CLUSTER_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    PROXY_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    TLS_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def credentials(self) -> global___BackendCredentialsContract: ...
    description: builtins.str
    @property
    def service_fabric_cluster(self) -> global___BackendServiceFabricClusterProperties: ...
    protocol: builtins.str
    @property
    def proxy(self) -> global___BackendProxyContract: ...
    resource_id: builtins.str
    title: builtins.str
    @property
    def tls(self) -> global___BackendTlsProperties: ...
    url: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        credentials: global___BackendCredentialsContract | None = ...,
        description: builtins.str = ...,
        service_fabric_cluster: global___BackendServiceFabricClusterProperties | None = ...,
        protocol: builtins.str = ...,
        proxy: global___BackendProxyContract | None = ...,
        resource_id: builtins.str = ...,
        title: builtins.str = ...,
        tls: global___BackendTlsProperties | None = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["credentials", b"credentials", "proxy", b"proxy", "resource_info", b"resource_info", "service_fabric_cluster", b"service_fabric_cluster", "tls", b"tls"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["credentials", b"credentials", "description", b"description", "name", b"name", "protocol", b"protocol", "proxy", b"proxy", "resource_id", b"resource_id", "resource_info", b"resource_info", "service_fabric_cluster", b"service_fabric_cluster", "title", b"title", "tls", b"tls", "url", b"url"]) -> None: ...

global___ServiceBackends = ServiceBackends

@typing_extensions.final
class BackendTlsProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALIDATE_CERTIFICATE_CHAIN_FIELD_NUMBER: builtins.int
    VALIDATE_CERTIFICATE_NAME_FIELD_NUMBER: builtins.int
    validate_certificate_chain: builtins.bool
    validate_certificate_name: builtins.bool
    def __init__(
        self,
        *,
        validate_certificate_chain: builtins.bool = ...,
        validate_certificate_name: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["validate_certificate_chain", b"validate_certificate_chain", "validate_certificate_name", b"validate_certificate_name"]) -> None: ...

global___BackendTlsProperties = BackendTlsProperties

@typing_extensions.final
class BackendProxyContract(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PASSWORD_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    password: builtins.str
    url: builtins.str
    username: builtins.str
    def __init__(
        self,
        *,
        password: builtins.str = ...,
        url: builtins.str = ...,
        username: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["password", b"password", "url", b"url", "username", b"username"]) -> None: ...

global___BackendProxyContract = BackendProxyContract

@typing_extensions.final
class BackendServiceFabricClusterProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_CERTIFICATE_ID_FIELD_NUMBER: builtins.int
    CLIENT_CERTIFICATETHUMBPRINT_FIELD_NUMBER: builtins.int
    MANAGEMENT_ENDPOINTS_FIELD_NUMBER: builtins.int
    MAX_PARTITION_RESOLUTION_RETRIES_FIELD_NUMBER: builtins.int
    SERVER_CERTIFICATE_THUMBPRINTS_FIELD_NUMBER: builtins.int
    SERVER_X509_NAMES_FIELD_NUMBER: builtins.int
    client_certificate_id: builtins.str
    client_certificatethumbprint: builtins.str
    @property
    def management_endpoints(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    max_partition_resolution_retries: builtins.int
    @property
    def server_certificate_thumbprints(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def server_x509_names(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___X509CertificateName]: ...
    def __init__(
        self,
        *,
        client_certificate_id: builtins.str = ...,
        client_certificatethumbprint: builtins.str = ...,
        management_endpoints: collections.abc.Iterable[builtins.str] | None = ...,
        max_partition_resolution_retries: builtins.int = ...,
        server_certificate_thumbprints: collections.abc.Iterable[builtins.str] | None = ...,
        server_x509_names: collections.abc.Iterable[global___X509CertificateName] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_certificate_id", b"client_certificate_id", "client_certificatethumbprint", b"client_certificatethumbprint", "management_endpoints", b"management_endpoints", "max_partition_resolution_retries", b"max_partition_resolution_retries", "server_certificate_thumbprints", b"server_certificate_thumbprints", "server_x509_names", b"server_x509_names"]) -> None: ...

global___BackendServiceFabricClusterProperties = BackendServiceFabricClusterProperties

@typing_extensions.final
class X509CertificateName(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ISSUER_CERTIFICATE_THUMBPRINT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    issuer_certificate_thumbprint: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        issuer_certificate_thumbprint: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["issuer_certificate_thumbprint", b"issuer_certificate_thumbprint", "name", b"name"]) -> None: ...

global___X509CertificateName = X509CertificateName

@typing_extensions.final
class BackendCredentialsContract(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class HeaderEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class QueryEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    AUTHORIZATION_FIELD_NUMBER: builtins.int
    CERTIFICATE_FIELD_NUMBER: builtins.int
    CERTIFICATE_IDS_FIELD_NUMBER: builtins.int
    HEADER_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    @property
    def authorization(self) -> global___BackendAuthorizationHeaderCredentials: ...
    @property
    def certificate(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def certificate_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def header(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def query(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        authorization: global___BackendAuthorizationHeaderCredentials | None = ...,
        certificate: collections.abc.Iterable[builtins.str] | None = ...,
        certificate_ids: collections.abc.Iterable[builtins.str] | None = ...,
        header: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        query: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authorization", b"authorization"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authorization", b"authorization", "certificate", b"certificate", "certificate_ids", b"certificate_ids", "header", b"header", "query", b"query"]) -> None: ...

global___BackendCredentialsContract = BackendCredentialsContract

@typing_extensions.final
class BackendAuthorizationHeaderCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMETER_FIELD_NUMBER: builtins.int
    SCHEME_FIELD_NUMBER: builtins.int
    parameter: builtins.str
    scheme: builtins.str
    def __init__(
        self,
        *,
        parameter: builtins.str = ...,
        scheme: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["parameter", b"parameter", "scheme", b"scheme"]) -> None: ...

global___BackendAuthorizationHeaderCredentials = BackendAuthorizationHeaderCredentials

@typing_extensions.final
class ServiceAuthorizationServers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTHORIZATION_ENDPOINT_FIELD_NUMBER: builtins.int
    AUTHORIZATION_METHODS_FIELD_NUMBER: builtins.int
    BEARER_TOKEN_SENDING_METHODS_FIELD_NUMBER: builtins.int
    CLIENT_AUTHENTICATION_METHOD_FIELD_NUMBER: builtins.int
    CLIENT_ID_FIELD_NUMBER: builtins.int
    CLIENT_REGISTRATION_ENDPOINT_FIELD_NUMBER: builtins.int
    CLIENT_SECRET_FIELD_NUMBER: builtins.int
    DEFAULT_SCOPE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    GRANT_TYPES_FIELD_NUMBER: builtins.int
    RESOURCE_OWNER_PASSWORD_FIELD_NUMBER: builtins.int
    RESOURCE_OWNER_USERNAME_FIELD_NUMBER: builtins.int
    SUPPORT_STATE_FIELD_NUMBER: builtins.int
    TOKEN_BODY_PARAMETERS_FIELD_NUMBER: builtins.int
    TOKEN_ENDPOINT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    authorization_endpoint: builtins.str
    @property
    def authorization_methods(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def bearer_token_sending_methods(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def client_authentication_method(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    client_id: builtins.str
    client_registration_endpoint: builtins.str
    client_secret: builtins.str
    default_scope: builtins.str
    description: builtins.str
    display_name: builtins.str
    @property
    def grant_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    resource_owner_password: builtins.str
    resource_owner_username: builtins.str
    support_state: builtins.bool
    @property
    def token_body_parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TokenBodyParameterContract]: ...
    token_endpoint: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        authorization_endpoint: builtins.str = ...,
        authorization_methods: collections.abc.Iterable[builtins.str] | None = ...,
        bearer_token_sending_methods: collections.abc.Iterable[builtins.str] | None = ...,
        client_authentication_method: collections.abc.Iterable[builtins.str] | None = ...,
        client_id: builtins.str = ...,
        client_registration_endpoint: builtins.str = ...,
        client_secret: builtins.str = ...,
        default_scope: builtins.str = ...,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        grant_types: collections.abc.Iterable[builtins.str] | None = ...,
        resource_owner_password: builtins.str = ...,
        resource_owner_username: builtins.str = ...,
        support_state: builtins.bool = ...,
        token_body_parameters: collections.abc.Iterable[global___TokenBodyParameterContract] | None = ...,
        token_endpoint: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authorization_endpoint", b"authorization_endpoint", "authorization_methods", b"authorization_methods", "bearer_token_sending_methods", b"bearer_token_sending_methods", "client_authentication_method", b"client_authentication_method", "client_id", b"client_id", "client_registration_endpoint", b"client_registration_endpoint", "client_secret", b"client_secret", "default_scope", b"default_scope", "description", b"description", "display_name", b"display_name", "grant_types", b"grant_types", "name", b"name", "resource_info", b"resource_info", "resource_owner_password", b"resource_owner_password", "resource_owner_username", b"resource_owner_username", "support_state", b"support_state", "token_body_parameters", b"token_body_parameters", "token_endpoint", b"token_endpoint"]) -> None: ...

global___ServiceAuthorizationServers = ServiceAuthorizationServers

@typing_extensions.final
class TokenBodyParameterContract(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "value", b"value"]) -> None: ...

global___TokenBodyParameterContract = TokenBodyParameterContract

@typing_extensions.final
class ServiceApiVersionSets(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    VERSION_HEADER_NAME_FIELD_NUMBER: builtins.int
    VERSIONING_SCHEME_FIELD_NUMBER: builtins.int
    VERSION_QUERY_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    description: builtins.str
    display_name: builtins.str
    version_header_name: builtins.str
    versioning_scheme: builtins.str
    version_query_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        version_header_name: builtins.str = ...,
        versioning_scheme: builtins.str = ...,
        version_query_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "display_name", b"display_name", "name", b"name", "resource_info", b"resource_info", "version_header_name", b"version_header_name", "version_query_name", b"version_query_name", "versioning_scheme", b"versioning_scheme"]) -> None: ...

global___ServiceApiVersionSets = ServiceApiVersionSets

@typing_extensions.final
class ServiceApisTags(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServiceApisTags = ServiceApisTags

@typing_extensions.final
class ServiceApisTagDescriptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXTERNAL_DOCS_DESCRIPTION_FIELD_NUMBER: builtins.int
    EXTERNAL_DOCS_URL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    description: builtins.str
    external_docs_description: builtins.str
    external_docs_url: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        external_docs_description: builtins.str = ...,
        external_docs_url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "external_docs_description", b"external_docs_description", "external_docs_url", b"external_docs_url", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServiceApisTagDescriptions = ServiceApisTagDescriptions

@typing_extensions.final
class ServiceApisSchemas(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CONTENT_TYPE_FIELD_NUMBER: builtins.int
    DOCUMENT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    content_type: builtins.str
    @property
    def document(self) -> global___SchemaDocumentProperties: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        content_type: builtins.str = ...,
        document: global___SchemaDocumentProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["document", b"document", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content_type", b"content_type", "document", b"document", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServiceApisSchemas = ServiceApisSchemas

@typing_extensions.final
class SchemaDocumentProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ComponentsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class DefinitionsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    COMPONENTS_FIELD_NUMBER: builtins.int
    DEFINITIONS_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def components(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def definitions(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    value: builtins.str
    def __init__(
        self,
        *,
        components: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        definitions: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["components", b"components", "definitions", b"definitions", "value", b"value"]) -> None: ...

global___SchemaDocumentProperties = SchemaDocumentProperties

@typing_extensions.final
class ServiceApisReleases(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    NOTES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    api_id: builtins.str
    notes: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        api_id: builtins.str = ...,
        notes: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "name", b"name", "notes", b"notes", "resource_info", b"resource_info"]) -> None: ...

global___ServiceApisReleases = ServiceApisReleases

@typing_extensions.final
class ServiceApisPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    format: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        format: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["format", b"format", "name", b"name", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___ServiceApisPolicies = ServiceApisPolicies

@typing_extensions.final
class ServiceApisOperationsTags(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___ServiceApisOperationsTags = ServiceApisOperationsTags

@typing_extensions.final
class ServiceApisOperationsPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    format: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        format: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["format", b"format", "name", b"name", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___ServiceApisOperationsPolicies = ServiceApisOperationsPolicies

@typing_extensions.final
class ServiceApisOperations(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    METHOD_FIELD_NUMBER: builtins.int
    POLICIES_FIELD_NUMBER: builtins.int
    REQUEST_FIELD_NUMBER: builtins.int
    RESPONSES_FIELD_NUMBER: builtins.int
    TEMPLATE_PARAMETERS_FIELD_NUMBER: builtins.int
    URL_TEMPLATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    description: builtins.str
    display_name: builtins.str
    method: builtins.str
    policies: builtins.str
    @property
    def request(self) -> global___RequestContract: ...
    @property
    def responses(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResponseContract]: ...
    @property
    def template_parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ParameterContract]: ...
    url_template: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        method: builtins.str = ...,
        policies: builtins.str = ...,
        request: global___RequestContract | None = ...,
        responses: collections.abc.Iterable[global___ResponseContract] | None = ...,
        template_parameters: collections.abc.Iterable[global___ParameterContract] | None = ...,
        url_template: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["request", b"request", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "display_name", b"display_name", "method", b"method", "name", b"name", "policies", b"policies", "request", b"request", "resource_info", b"resource_info", "responses", b"responses", "template_parameters", b"template_parameters", "url_template", b"url_template"]) -> None: ...

global___ServiceApisOperations = ServiceApisOperations

@typing_extensions.final
class ResponseContract(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    HEADERS_FIELD_NUMBER: builtins.int
    REPRESENTATIONS_FIELD_NUMBER: builtins.int
    STATUS_CODE_FIELD_NUMBER: builtins.int
    description: builtins.str
    @property
    def headers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ParameterContract]: ...
    @property
    def representations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RepresentationContract]: ...
    status_code: builtins.int
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        headers: collections.abc.Iterable[global___ParameterContract] | None = ...,
        representations: collections.abc.Iterable[global___RepresentationContract] | None = ...,
        status_code: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "headers", b"headers", "representations", b"representations", "status_code", b"status_code"]) -> None: ...

global___ResponseContract = ResponseContract

@typing_extensions.final
class RequestContract(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    HEADERS_FIELD_NUMBER: builtins.int
    QUERY_PARAMETERS_FIELD_NUMBER: builtins.int
    REPRESENTATIONS_FIELD_NUMBER: builtins.int
    description: builtins.str
    @property
    def headers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ParameterContract]: ...
    @property
    def query_parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ParameterContract]: ...
    @property
    def representations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RepresentationContract]: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        headers: collections.abc.Iterable[global___ParameterContract] | None = ...,
        query_parameters: collections.abc.Iterable[global___ParameterContract] | None = ...,
        representations: collections.abc.Iterable[global___RepresentationContract] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "headers", b"headers", "query_parameters", b"query_parameters", "representations", b"representations"]) -> None: ...

global___RequestContract = RequestContract

@typing_extensions.final
class RepresentationContract(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ExamplesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONTENT_TYPE_FIELD_NUMBER: builtins.int
    EXAMPLES_FIELD_NUMBER: builtins.int
    FORM_PARAMETERS_FIELD_NUMBER: builtins.int
    SCHEMA_ID_FIELD_NUMBER: builtins.int
    TYPE_NAME_FIELD_NUMBER: builtins.int
    content_type: builtins.str
    @property
    def examples(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def form_parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ParameterContract]: ...
    schema_id: builtins.str
    type_name: builtins.str
    def __init__(
        self,
        *,
        content_type: builtins.str = ...,
        examples: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        form_parameters: collections.abc.Iterable[global___ParameterContract] | None = ...,
        schema_id: builtins.str = ...,
        type_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content_type", b"content_type", "examples", b"examples", "form_parameters", b"form_parameters", "schema_id", b"schema_id", "type_name", b"type_name"]) -> None: ...

global___RepresentationContract = RepresentationContract

@typing_extensions.final
class ParameterContract(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ExamplesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXAMPLES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    REQUIRED_FIELD_NUMBER: builtins.int
    SCHEMA_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    TYPE_NAME_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    default_value: builtins.str
    description: builtins.str
    @property
    def examples(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    required: builtins.bool
    schema_id: builtins.str
    type: builtins.str
    type_name: builtins.str
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        default_value: builtins.str = ...,
        description: builtins.str = ...,
        examples: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        required: builtins.bool = ...,
        schema_id: builtins.str = ...,
        type: builtins.str = ...,
        type_name: builtins.str = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_value", b"default_value", "description", b"description", "examples", b"examples", "name", b"name", "required", b"required", "schema_id", b"schema_id", "type", b"type", "type_name", b"type_name", "values", b"values"]) -> None: ...

global___ParameterContract = ParameterContract

@typing_extensions.final
class ServiceApisIssuesComments(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CREATED_DATE_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    created_date: builtins.str
    text: builtins.str
    user_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        created_date: builtins.str = ...,
        text: builtins.str = ...,
        user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_date", b"created_date", "name", b"name", "resource_info", b"resource_info", "text", b"text", "user_id", b"user_id"]) -> None: ...

global___ServiceApisIssuesComments = ServiceApisIssuesComments

@typing_extensions.final
class ServiceApisIssuesAttachments(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    CONTENT_FORMAT_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    content: builtins.str
    content_format: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        content: builtins.str = ...,
        content_format: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "content_format", b"content_format", "name", b"name", "resource_info", b"resource_info", "title", b"title"]) -> None: ...

global___ServiceApisIssuesAttachments = ServiceApisIssuesAttachments

@typing_extensions.final
class ServiceApisIssues(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    API_ID_FIELD_NUMBER: builtins.int
    CREATED_DATE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    SERVICE_APIS_ISSUES_COMMENTS_FIELD_NUMBER: builtins.int
    SERVICE_APIS_ISSUES_ATTACHMENTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    api_id: builtins.str
    created_date: builtins.str
    description: builtins.str
    state: builtins.str
    title: builtins.str
    user_id: builtins.str
    @property
    def service_apis_issues_comments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceApisIssuesComments]: ...
    @property
    def service_apis_issues_attachments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceApisIssuesAttachments]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        api_id: builtins.str = ...,
        created_date: builtins.str = ...,
        description: builtins.str = ...,
        state: builtins.str = ...,
        title: builtins.str = ...,
        user_id: builtins.str = ...,
        service_apis_issues_comments: collections.abc.Iterable[global___ServiceApisIssuesComments] | None = ...,
        service_apis_issues_attachments: collections.abc.Iterable[global___ServiceApisIssuesAttachments] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_id", b"api_id", "created_date", b"created_date", "description", b"description", "name", b"name", "resource_info", b"resource_info", "service_apis_issues_attachments", b"service_apis_issues_attachments", "service_apis_issues_comments", b"service_apis_issues_comments", "state", b"state", "title", b"title", "user_id", b"user_id"]) -> None: ...

global___ServiceApisIssues = ServiceApisIssues

@typing_extensions.final
class ServiceApisDiagnostics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ALWAYS_LOG_FIELD_NUMBER: builtins.int
    BACKEND_FIELD_NUMBER: builtins.int
    FRONTEND_FIELD_NUMBER: builtins.int
    HTTP_CORRELATION_PROTOCOL_FIELD_NUMBER: builtins.int
    LOG_CLIENT_IP_FIELD_NUMBER: builtins.int
    LOGGER_ID_FIELD_NUMBER: builtins.int
    OPERATION_NAME_FORMAT_FIELD_NUMBER: builtins.int
    SAMPLING_FIELD_NUMBER: builtins.int
    VERBOSITY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    always_log: builtins.str
    @property
    def backend(self) -> global___PipelineDiagnosticSettings: ...
    @property
    def frontend(self) -> global___PipelineDiagnosticSettings: ...
    http_correlation_protocol: builtins.str
    log_client_ip: builtins.bool
    logger_id: builtins.str
    operation_name_format: builtins.str
    @property
    def sampling(self) -> global___SamplingSettings: ...
    verbosity: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        always_log: builtins.str = ...,
        backend: global___PipelineDiagnosticSettings | None = ...,
        frontend: global___PipelineDiagnosticSettings | None = ...,
        http_correlation_protocol: builtins.str = ...,
        log_client_ip: builtins.bool = ...,
        logger_id: builtins.str = ...,
        operation_name_format: builtins.str = ...,
        sampling: global___SamplingSettings | None = ...,
        verbosity: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["backend", b"backend", "frontend", b"frontend", "resource_info", b"resource_info", "sampling", b"sampling"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["always_log", b"always_log", "backend", b"backend", "frontend", b"frontend", "http_correlation_protocol", b"http_correlation_protocol", "log_client_ip", b"log_client_ip", "logger_id", b"logger_id", "name", b"name", "operation_name_format", b"operation_name_format", "resource_info", b"resource_info", "sampling", b"sampling", "verbosity", b"verbosity"]) -> None: ...

global___ServiceApisDiagnostics = ServiceApisDiagnostics

@typing_extensions.final
class SamplingSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PERCENTAGE_FIELD_NUMBER: builtins.int
    SAMPLING_TYPE_FIELD_NUMBER: builtins.int
    percentage: builtins.float
    sampling_type: builtins.str
    def __init__(
        self,
        *,
        percentage: builtins.float = ...,
        sampling_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["percentage", b"percentage", "sampling_type", b"sampling_type"]) -> None: ...

global___SamplingSettings = SamplingSettings

@typing_extensions.final
class PipelineDiagnosticSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_FIELD_NUMBER: builtins.int
    RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def request(self) -> global___HttpMessageDiagnostic: ...
    @property
    def response(self) -> global___HttpMessageDiagnostic: ...
    def __init__(
        self,
        *,
        request: global___HttpMessageDiagnostic | None = ...,
        response: global___HttpMessageDiagnostic | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["request", b"request", "response", b"response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["request", b"request", "response", b"response"]) -> None: ...

global___PipelineDiagnosticSettings = PipelineDiagnosticSettings

@typing_extensions.final
class HttpMessageDiagnostic(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BODY_FIELD_NUMBER: builtins.int
    DATA_MASKING_FIELD_NUMBER: builtins.int
    HEADERS_FIELD_NUMBER: builtins.int
    @property
    def body(self) -> global___BodyDiagnosticSettings: ...
    @property
    def data_masking(self) -> global___DataMasking: ...
    @property
    def headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        body: global___BodyDiagnosticSettings | None = ...,
        data_masking: global___DataMasking | None = ...,
        headers: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["body", b"body", "data_masking", b"data_masking"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["body", b"body", "data_masking", b"data_masking", "headers", b"headers"]) -> None: ...

global___HttpMessageDiagnostic = HttpMessageDiagnostic

@typing_extensions.final
class DataMasking(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADERS_FIELD_NUMBER: builtins.int
    QUERY_PARAMS_FIELD_NUMBER: builtins.int
    @property
    def headers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataMaskingEntity]: ...
    @property
    def query_params(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DataMaskingEntity]: ...
    def __init__(
        self,
        *,
        headers: collections.abc.Iterable[global___DataMaskingEntity] | None = ...,
        query_params: collections.abc.Iterable[global___DataMaskingEntity] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["headers", b"headers", "query_params", b"query_params"]) -> None: ...

global___DataMasking = DataMasking

@typing_extensions.final
class DataMaskingEntity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODE_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    mode: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        mode: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mode", b"mode", "value", b"value"]) -> None: ...

global___DataMaskingEntity = DataMaskingEntity

@typing_extensions.final
class BodyDiagnosticSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BYTES_FIELD_NUMBER: builtins.int
    bytes: builtins.int
    def __init__(
        self,
        *,
        bytes: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bytes", b"bytes"]) -> None: ...

global___BodyDiagnosticSettings = BodyDiagnosticSettings

@typing_extensions.final
class ServiceApis(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    API_REVISION_FIELD_NUMBER: builtins.int
    API_REVISION_DESCRIPTION_FIELD_NUMBER: builtins.int
    API_TYPE_FIELD_NUMBER: builtins.int
    API_VERSION_DESCRIPTION_FIELD_NUMBER: builtins.int
    API_VERSION_SET_FIELD_NUMBER: builtins.int
    API_VERSION_SET_ID_FIELD_NUMBER: builtins.int
    AUTHENTICATION_SETTINGS_FIELD_NUMBER: builtins.int
    CONTACT_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    IS_CURRENT_FIELD_NUMBER: builtins.int
    LICENSE_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    PROTOCOLS_FIELD_NUMBER: builtins.int
    SERVICE_URL_FIELD_NUMBER: builtins.int
    SOURCE_API_ID_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_KEY_PARAMETER_NAMES_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_REQUIRED_FIELD_NUMBER: builtins.int
    TERMS_OF_SERVICE_URL_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    WSDL_SELECTOR_FIELD_NUMBER: builtins.int
    SERVICE_APIS_RELEASES_FIELD_NUMBER: builtins.int
    SERVICE_APIS_SCHEMAS_FIELD_NUMBER: builtins.int
    SERVICE_APIS_ISSUES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    api_revision: builtins.str
    api_revision_description: builtins.str
    api_type: builtins.str
    api_version_description: builtins.str
    @property
    def api_version_set(self) -> global___ApiVersionSetContractDetails: ...
    api_version_set_id: builtins.str
    @property
    def authentication_settings(self) -> global___AuthenticationSettingsContract: ...
    @property
    def contact(self) -> global___ApiContactInformation: ...
    description: builtins.str
    display_name: builtins.str
    format: builtins.str
    is_current: builtins.bool
    @property
    def license(self) -> global___ApiLicenseInformation: ...
    path: builtins.str
    @property
    def protocols(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    service_url: builtins.str
    source_api_id: builtins.str
    @property
    def subscription_key_parameter_names(self) -> global___SubscriptionKeyParameterNamesContract: ...
    subscription_required: builtins.bool
    terms_of_service_url: builtins.str
    type: builtins.str
    value: builtins.str
    @property
    def wsdl_selector(self) -> global___ApiCreateOrUpdatePropertiesWsdlSelector: ...
    @property
    def service_apis_releases(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceApisReleases]: ...
    @property
    def service_apis_schemas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceApisSchemas]: ...
    @property
    def service_apis_issues(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceApisIssues]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        api_revision: builtins.str = ...,
        api_revision_description: builtins.str = ...,
        api_type: builtins.str = ...,
        api_version_description: builtins.str = ...,
        api_version_set: global___ApiVersionSetContractDetails | None = ...,
        api_version_set_id: builtins.str = ...,
        authentication_settings: global___AuthenticationSettingsContract | None = ...,
        contact: global___ApiContactInformation | None = ...,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        format: builtins.str = ...,
        is_current: builtins.bool = ...,
        license: global___ApiLicenseInformation | None = ...,
        path: builtins.str = ...,
        protocols: collections.abc.Iterable[builtins.str] | None = ...,
        service_url: builtins.str = ...,
        source_api_id: builtins.str = ...,
        subscription_key_parameter_names: global___SubscriptionKeyParameterNamesContract | None = ...,
        subscription_required: builtins.bool = ...,
        terms_of_service_url: builtins.str = ...,
        type: builtins.str = ...,
        value: builtins.str = ...,
        wsdl_selector: global___ApiCreateOrUpdatePropertiesWsdlSelector | None = ...,
        service_apis_releases: collections.abc.Iterable[global___ServiceApisReleases] | None = ...,
        service_apis_schemas: collections.abc.Iterable[global___ServiceApisSchemas] | None = ...,
        service_apis_issues: collections.abc.Iterable[global___ServiceApisIssues] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["api_version_set", b"api_version_set", "authentication_settings", b"authentication_settings", "contact", b"contact", "license", b"license", "resource_info", b"resource_info", "subscription_key_parameter_names", b"subscription_key_parameter_names", "wsdl_selector", b"wsdl_selector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_revision", b"api_revision", "api_revision_description", b"api_revision_description", "api_type", b"api_type", "api_version_description", b"api_version_description", "api_version_set", b"api_version_set", "api_version_set_id", b"api_version_set_id", "authentication_settings", b"authentication_settings", "contact", b"contact", "description", b"description", "display_name", b"display_name", "format", b"format", "is_current", b"is_current", "license", b"license", "name", b"name", "path", b"path", "protocols", b"protocols", "resource_info", b"resource_info", "service_apis_issues", b"service_apis_issues", "service_apis_releases", b"service_apis_releases", "service_apis_schemas", b"service_apis_schemas", "service_url", b"service_url", "source_api_id", b"source_api_id", "subscription_key_parameter_names", b"subscription_key_parameter_names", "subscription_required", b"subscription_required", "terms_of_service_url", b"terms_of_service_url", "type", b"type", "value", b"value", "wsdl_selector", b"wsdl_selector"]) -> None: ...

global___ServiceApis = ServiceApis

@typing_extensions.final
class ApiCreateOrUpdatePropertiesWsdlSelector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WSDL_ENDPOINT_NAME_FIELD_NUMBER: builtins.int
    WSDL_SERVICE_NAME_FIELD_NUMBER: builtins.int
    wsdl_endpoint_name: builtins.str
    wsdl_service_name: builtins.str
    def __init__(
        self,
        *,
        wsdl_endpoint_name: builtins.str = ...,
        wsdl_service_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["wsdl_endpoint_name", b"wsdl_endpoint_name", "wsdl_service_name", b"wsdl_service_name"]) -> None: ...

global___ApiCreateOrUpdatePropertiesWsdlSelector = ApiCreateOrUpdatePropertiesWsdlSelector

@typing_extensions.final
class SubscriptionKeyParameterNamesContract(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    header: builtins.str
    query: builtins.str
    def __init__(
        self,
        *,
        header: builtins.str = ...,
        query: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header", b"header", "query", b"query"]) -> None: ...

global___SubscriptionKeyParameterNamesContract = SubscriptionKeyParameterNamesContract

@typing_extensions.final
class ApiLicenseInformation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    name: builtins.str
    url: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "url", b"url"]) -> None: ...

global___ApiLicenseInformation = ApiLicenseInformation

@typing_extensions.final
class ApiContactInformation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMAIL_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    email: builtins.str
    name: builtins.str
    url: builtins.str
    def __init__(
        self,
        *,
        email: builtins.str = ...,
        name: builtins.str = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["email", b"email", "name", b"name", "url", b"url"]) -> None: ...

global___ApiContactInformation = ApiContactInformation

@typing_extensions.final
class AuthenticationSettingsContract(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    O_AUTH2_FIELD_NUMBER: builtins.int
    OPENID_FIELD_NUMBER: builtins.int
    @property
    def o_auth2(self) -> global___OAuth2AuthenticationSettingsContract: ...
    @property
    def openid(self) -> global___OpenIdAuthenticationSettingsContract: ...
    def __init__(
        self,
        *,
        o_auth2: global___OAuth2AuthenticationSettingsContract | None = ...,
        openid: global___OpenIdAuthenticationSettingsContract | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["o_auth2", b"o_auth2", "openid", b"openid"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["o_auth2", b"o_auth2", "openid", b"openid"]) -> None: ...

global___AuthenticationSettingsContract = AuthenticationSettingsContract

@typing_extensions.final
class OpenIdAuthenticationSettingsContract(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BEARER_TOKEN_SENDING_METHODS_FIELD_NUMBER: builtins.int
    OPENID_PROVIDER_ID_FIELD_NUMBER: builtins.int
    @property
    def bearer_token_sending_methods(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    openid_provider_id: builtins.str
    def __init__(
        self,
        *,
        bearer_token_sending_methods: collections.abc.Iterable[builtins.str] | None = ...,
        openid_provider_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bearer_token_sending_methods", b"bearer_token_sending_methods", "openid_provider_id", b"openid_provider_id"]) -> None: ...

global___OpenIdAuthenticationSettingsContract = OpenIdAuthenticationSettingsContract

@typing_extensions.final
class OAuth2AuthenticationSettingsContract(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHORIZATION_SERVER_ID_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    authorization_server_id: builtins.str
    scope: builtins.str
    def __init__(
        self,
        *,
        authorization_server_id: builtins.str = ...,
        scope: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["authorization_server_id", b"authorization_server_id", "scope", b"scope"]) -> None: ...

global___OAuth2AuthenticationSettingsContract = OAuth2AuthenticationSettingsContract

@typing_extensions.final
class ApiVersionSetContractDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VERSION_HEADER_NAME_FIELD_NUMBER: builtins.int
    VERSIONING_SCHEME_FIELD_NUMBER: builtins.int
    VERSION_QUERY_NAME_FIELD_NUMBER: builtins.int
    description: builtins.str
    id: builtins.str
    name: builtins.str
    version_header_name: builtins.str
    versioning_scheme: builtins.str
    version_query_name: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        version_header_name: builtins.str = ...,
        versioning_scheme: builtins.str = ...,
        version_query_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "id", b"id", "name", b"name", "version_header_name", b"version_header_name", "version_query_name", b"version_query_name", "versioning_scheme", b"versioning_scheme"]) -> None: ...

global___ApiVersionSetContractDetails = ApiVersionSetContractDetails

@typing_extensions.final
class Service(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class CustomPropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ADDITIONAL_LOCATIONS_FIELD_NUMBER: builtins.int
    API_VERSION_CONSTRAINT_FIELD_NUMBER: builtins.int
    CERTIFICATES_FIELD_NUMBER: builtins.int
    CUSTOM_PROPERTIES_FIELD_NUMBER: builtins.int
    DISABLE_GATEWAY_FIELD_NUMBER: builtins.int
    ENABLE_CLIENT_CERTIFICATE_FIELD_NUMBER: builtins.int
    HOSTNAME_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    NOTIFICATION_SENDER_EMAIL_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    PUBLIC_IP_ADDRESS_ID_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    PUBLISHER_EMAIL_FIELD_NUMBER: builtins.int
    PUBLISHER_NAME_FIELD_NUMBER: builtins.int
    RESTORE_FIELD_NUMBER: builtins.int
    VIRTUAL_NETWORK_CONFIGURATION_FIELD_NUMBER: builtins.int
    VIRTUAL_NETWORK_TYPE_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    ZONES_FIELD_NUMBER: builtins.int
    SERVICE_TAGS_FIELD_NUMBER: builtins.int
    SERVICE_CACHES_FIELD_NUMBER: builtins.int
    SERVICE_CONTENT_TYPES_FIELD_NUMBER: builtins.int
    SERVICE_TEMPLATES_FIELD_NUMBER: builtins.int
    SERVICE_PORTAL_REVISIONS_FIELD_NUMBER: builtins.int
    SERVICE_PORTALSETTINGS_FIELD_NUMBER: builtins.int
    SERVICE_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    SERVICE_SCHEMAS_FIELD_NUMBER: builtins.int
    SERVICE_TENANT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___ApiManagementServiceIdentity: ...
    location: builtins.str
    name: builtins.str
    @property
    def additional_locations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AdditionalLocation]: ...
    @property
    def api_version_constraint(self) -> global___ApiVersionConstraint: ...
    @property
    def certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CertificateConfiguration]: ...
    @property
    def custom_properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    disable_gateway: builtins.bool
    enable_client_certificate: builtins.bool
    @property
    def hostname_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HostnameConfiguration]: ...
    notification_sender_email: builtins.str
    @property
    def private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RemotePrivateEndpointConnectionWrapper]: ...
    public_ip_address_id: builtins.str
    public_network_access: builtins.str
    publisher_email: builtins.str
    publisher_name: builtins.str
    restore: builtins.bool
    @property
    def virtual_network_configuration(self) -> global___VirtualNetworkConfiguration: ...
    virtual_network_type: builtins.str
    @property
    def sku(self) -> global___ApiManagementServiceSkuProperties: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def zones(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def service_tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceTags]: ...
    @property
    def service_caches(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceCaches]: ...
    @property
    def service_content_types(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceContentTypes]: ...
    @property
    def service_templates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceTemplates]: ...
    @property
    def service_portal_revisions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServicePortalRevisions]: ...
    @property
    def service_portalsettings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServicePortalsettings]: ...
    @property
    def service_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServicePrivateEndpointConnections]: ...
    @property
    def service_schemas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceSchemas]: ...
    @property
    def service_tenant(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceTenant]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___ApiManagementServiceIdentity | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        additional_locations: collections.abc.Iterable[global___AdditionalLocation] | None = ...,
        api_version_constraint: global___ApiVersionConstraint | None = ...,
        certificates: collections.abc.Iterable[global___CertificateConfiguration] | None = ...,
        custom_properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        disable_gateway: builtins.bool = ...,
        enable_client_certificate: builtins.bool = ...,
        hostname_configurations: collections.abc.Iterable[global___HostnameConfiguration] | None = ...,
        notification_sender_email: builtins.str = ...,
        private_endpoint_connections: collections.abc.Iterable[global___RemotePrivateEndpointConnectionWrapper] | None = ...,
        public_ip_address_id: builtins.str = ...,
        public_network_access: builtins.str = ...,
        publisher_email: builtins.str = ...,
        publisher_name: builtins.str = ...,
        restore: builtins.bool = ...,
        virtual_network_configuration: global___VirtualNetworkConfiguration | None = ...,
        virtual_network_type: builtins.str = ...,
        sku: global___ApiManagementServiceSkuProperties | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        zones: collections.abc.Iterable[builtins.str] | None = ...,
        service_tags: collections.abc.Iterable[global___ServiceTags] | None = ...,
        service_caches: collections.abc.Iterable[global___ServiceCaches] | None = ...,
        service_content_types: collections.abc.Iterable[global___ServiceContentTypes] | None = ...,
        service_templates: collections.abc.Iterable[global___ServiceTemplates] | None = ...,
        service_portal_revisions: collections.abc.Iterable[global___ServicePortalRevisions] | None = ...,
        service_portalsettings: collections.abc.Iterable[global___ServicePortalsettings] | None = ...,
        service_private_endpoint_connections: collections.abc.Iterable[global___ServicePrivateEndpointConnections] | None = ...,
        service_schemas: collections.abc.Iterable[global___ServiceSchemas] | None = ...,
        service_tenant: collections.abc.Iterable[global___ServiceTenant] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["api_version_constraint", b"api_version_constraint", "identity", b"identity", "resource_info", b"resource_info", "sku", b"sku", "virtual_network_configuration", b"virtual_network_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_locations", b"additional_locations", "api_version_constraint", b"api_version_constraint", "certificates", b"certificates", "custom_properties", b"custom_properties", "disable_gateway", b"disable_gateway", "enable_client_certificate", b"enable_client_certificate", "hostname_configurations", b"hostname_configurations", "identity", b"identity", "location", b"location", "name", b"name", "notification_sender_email", b"notification_sender_email", "private_endpoint_connections", b"private_endpoint_connections", "public_ip_address_id", b"public_ip_address_id", "public_network_access", b"public_network_access", "publisher_email", b"publisher_email", "publisher_name", b"publisher_name", "resource_info", b"resource_info", "restore", b"restore", "service_caches", b"service_caches", "service_content_types", b"service_content_types", "service_portal_revisions", b"service_portal_revisions", "service_portalsettings", b"service_portalsettings", "service_private_endpoint_connections", b"service_private_endpoint_connections", "service_schemas", b"service_schemas", "service_tags", b"service_tags", "service_templates", b"service_templates", "service_tenant", b"service_tenant", "sku", b"sku", "tags", b"tags", "virtual_network_configuration", b"virtual_network_configuration", "virtual_network_type", b"virtual_network_type", "zones", b"zones"]) -> None: ...

global___Service = Service

@typing_extensions.final
class RemotePrivateEndpointConnectionWrapper(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    id: builtins.str
    name: builtins.str
    @property
    def private_endpoint(self) -> global___ArmIdWrapper: ...
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkServiceConnectionState: ...
    type: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        private_endpoint: global___ArmIdWrapper | None = ...,
        private_link_service_connection_state: global___PrivateLinkServiceConnectionState | None = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "name", b"name", "private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "type", b"type"]) -> None: ...

global___RemotePrivateEndpointConnectionWrapper = RemotePrivateEndpointConnectionWrapper

@typing_extensions.final
class PrivateLinkServiceConnectionState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIONS_REQUIRED_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    actions_required: builtins.str
    description: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        actions_required: builtins.str = ...,
        description: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions_required", b"actions_required", "description", b"description", "status", b"status"]) -> None: ...

global___PrivateLinkServiceConnectionState = PrivateLinkServiceConnectionState

@typing_extensions.final
class ArmIdWrapper(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___ArmIdWrapper = ArmIdWrapper

@typing_extensions.final
class HostnameConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_FIELD_NUMBER: builtins.int
    CERTIFICATE_PASSWORD_FIELD_NUMBER: builtins.int
    CERTIFICATE_SOURCE_FIELD_NUMBER: builtins.int
    CERTIFICATE_STATUS_FIELD_NUMBER: builtins.int
    DEFAULT_SSL_BINDING_FIELD_NUMBER: builtins.int
    ENCODED_CERTIFICATE_FIELD_NUMBER: builtins.int
    HOST_NAME_FIELD_NUMBER: builtins.int
    IDENTITY_CLIENT_ID_FIELD_NUMBER: builtins.int
    KEY_VAULT_ID_FIELD_NUMBER: builtins.int
    NEGOTIATE_CLIENT_CERTIFICATE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    @property
    def certificate(self) -> global___CertificateInformation: ...
    certificate_password: builtins.str
    certificate_source: builtins.str
    certificate_status: builtins.str
    default_ssl_binding: builtins.bool
    encoded_certificate: builtins.str
    host_name: builtins.str
    identity_client_id: builtins.str
    key_vault_id: builtins.str
    negotiate_client_certificate: builtins.bool
    type: builtins.str
    def __init__(
        self,
        *,
        certificate: global___CertificateInformation | None = ...,
        certificate_password: builtins.str = ...,
        certificate_source: builtins.str = ...,
        certificate_status: builtins.str = ...,
        default_ssl_binding: builtins.bool = ...,
        encoded_certificate: builtins.str = ...,
        host_name: builtins.str = ...,
        identity_client_id: builtins.str = ...,
        key_vault_id: builtins.str = ...,
        negotiate_client_certificate: builtins.bool = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["certificate", b"certificate"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate", b"certificate", "certificate_password", b"certificate_password", "certificate_source", b"certificate_source", "certificate_status", b"certificate_status", "default_ssl_binding", b"default_ssl_binding", "encoded_certificate", b"encoded_certificate", "host_name", b"host_name", "identity_client_id", b"identity_client_id", "key_vault_id", b"key_vault_id", "negotiate_client_certificate", b"negotiate_client_certificate", "type", b"type"]) -> None: ...

global___HostnameConfiguration = HostnameConfiguration

@typing_extensions.final
class CertificateConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_FIELD_NUMBER: builtins.int
    CERTIFICATE_PASSWORD_FIELD_NUMBER: builtins.int
    ENCODED_CERTIFICATE_FIELD_NUMBER: builtins.int
    STORE_NAME_FIELD_NUMBER: builtins.int
    @property
    def certificate(self) -> global___CertificateInformation: ...
    certificate_password: builtins.str
    encoded_certificate: builtins.str
    store_name: builtins.str
    def __init__(
        self,
        *,
        certificate: global___CertificateInformation | None = ...,
        certificate_password: builtins.str = ...,
        encoded_certificate: builtins.str = ...,
        store_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["certificate", b"certificate"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate", b"certificate", "certificate_password", b"certificate_password", "encoded_certificate", b"encoded_certificate", "store_name", b"store_name"]) -> None: ...

global___CertificateConfiguration = CertificateConfiguration

@typing_extensions.final
class CertificateInformation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPIRY_FIELD_NUMBER: builtins.int
    SUBJECT_FIELD_NUMBER: builtins.int
    THUMBPRINT_FIELD_NUMBER: builtins.int
    expiry: builtins.str
    subject: builtins.str
    thumbprint: builtins.str
    def __init__(
        self,
        *,
        expiry: builtins.str = ...,
        subject: builtins.str = ...,
        thumbprint: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["expiry", b"expiry", "subject", b"subject", "thumbprint", b"thumbprint"]) -> None: ...

global___CertificateInformation = CertificateInformation

@typing_extensions.final
class ApiVersionConstraint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_API_VERSION_FIELD_NUMBER: builtins.int
    min_api_version: builtins.str
    def __init__(
        self,
        *,
        min_api_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["min_api_version", b"min_api_version"]) -> None: ...

global___ApiVersionConstraint = ApiVersionConstraint

@typing_extensions.final
class AdditionalLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLE_GATEWAY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    PUBLIC_IP_ADDRESS_ID_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    VIRTUAL_NETWORK_CONFIGURATION_FIELD_NUMBER: builtins.int
    ZONES_FIELD_NUMBER: builtins.int
    disable_gateway: builtins.bool
    location: builtins.str
    public_ip_address_id: builtins.str
    @property
    def sku(self) -> global___ApiManagementServiceSkuProperties: ...
    @property
    def virtual_network_configuration(self) -> global___VirtualNetworkConfiguration: ...
    @property
    def zones(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        disable_gateway: builtins.bool = ...,
        location: builtins.str = ...,
        public_ip_address_id: builtins.str = ...,
        sku: global___ApiManagementServiceSkuProperties | None = ...,
        virtual_network_configuration: global___VirtualNetworkConfiguration | None = ...,
        zones: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["sku", b"sku", "virtual_network_configuration", b"virtual_network_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disable_gateway", b"disable_gateway", "location", b"location", "public_ip_address_id", b"public_ip_address_id", "sku", b"sku", "virtual_network_configuration", b"virtual_network_configuration", "zones", b"zones"]) -> None: ...

global___AdditionalLocation = AdditionalLocation

@typing_extensions.final
class VirtualNetworkConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBNET_RESOURCE_ID_FIELD_NUMBER: builtins.int
    subnet_resource_id: builtins.str
    def __init__(
        self,
        *,
        subnet_resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["subnet_resource_id", b"subnet_resource_id"]) -> None: ...

global___VirtualNetworkConfiguration = VirtualNetworkConfiguration

@typing_extensions.final
class ApiManagementServiceSkuProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPACITY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    capacity: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        capacity: builtins.int = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["capacity", b"capacity", "name", b"name"]) -> None: ...

global___ApiManagementServiceSkuProperties = ApiManagementServiceSkuProperties

@typing_extensions.final
class ApiManagementServiceIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___ApiManagementServiceIdentity = ApiManagementServiceIdentity
